<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>AudioCaptureSession</name>
    <message>
        <source>RAW file format</source>
        <translation type="vanished">Файл формату RAW</translation>
    </message>
    <message>
        <source>WAV file format</source>
        <translation type="vanished">Файл формату WAV</translation>
    </message>
</context>
<context>
    <name>AudioContainerControl</name>
    <message>
        <source>RAW (headerless) file format</source>
        <translation>Файл формату RAW (без заголовку)</translation>
    </message>
    <message>
        <source>WAV file format</source>
        <translation>Файл формату WAV</translation>
    </message>
</context>
<context>
    <name>AudioEncoderControl</name>
    <message>
        <source>PCM audio data</source>
        <translation type="vanished">Аудіо-дані PCM</translation>
    </message>
    <message>
        <source>Linear PCM audio data</source>
        <translation>Лінійні аудіо-дані PCM</translation>
    </message>
</context>
<context>
    <name>BbCameraAudioEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation>Без стиснення</translation>
    </message>
    <message>
        <source>AAC compression</source>
        <translation>Стиснення AAC</translation>
    </message>
    <message>
        <source>PCM uncompressed</source>
        <translation>Без стиснення PCM</translation>
    </message>
</context>
<context>
    <name>BbCameraMediaRecorderControl</name>
    <message>
        <source>Unable to retrieve mute status</source>
        <translation>Неможливо отримати стан вимкнення звуку</translation>
    </message>
    <message>
        <source>Unable to retrieve audio input volume</source>
        <translation>Неможливо отримати гучність вхідного звуку</translation>
    </message>
    <message>
        <source>Unable to set mute status</source>
        <translation>Неможливо встановити стан вимкнення звуку</translation>
    </message>
    <message>
        <source>Unable to set audio input volume</source>
        <translation>Неможливо встановити гучність вхідного звуку</translation>
    </message>
</context>
<context>
    <name>BbCameraSession</name>
    <message>
        <source>Camera provides image in unsupported format</source>
        <translation>Камера надає зображення в форматі, що не підтримується</translation>
    </message>
    <message>
        <source>Could not load JPEG data from frame</source>
        <translation>Не вдалось завантажити дані JPEG з кадру</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation>Камера не готова</translation>
    </message>
    <message>
        <source>Unable to apply video settings</source>
        <translation>Неможливо застосувати налаштування відео</translation>
    </message>
    <message>
        <source>Could not open destination file:
%1</source>
        <translation>Не вдалось відкрити файл-отримувач:
%1</translation>
    </message>
    <message>
        <source>Unable to open camera</source>
        <translation>Неможливо відкрити камеру</translation>
    </message>
    <message>
        <source>Unable to retrieve native camera orientation</source>
        <translation>Неможливо отримати рідну орієнтацію камери</translation>
    </message>
    <message>
        <source>Unable to close camera</source>
        <translation>Неможливо закрити камеру</translation>
    </message>
    <message>
        <source>Unable to start video recording</source>
        <translation>Неможливо розпочати запис відео</translation>
    </message>
    <message>
        <source>Unable to stop video recording</source>
        <translation>Неможливо закінчити запис відео</translation>
    </message>
</context>
<context>
    <name>BbCameraVideoEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation>Без стиснення</translation>
    </message>
    <message>
        <source>AVC1 compression</source>
        <translation>Стиснення AVC1</translation>
    </message>
    <message>
        <source>H264 compression</source>
        <translation>Стиснення H264</translation>
    </message>
</context>
<context>
    <name>BbImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>Зображення JPEG</translation>
    </message>
</context>
<context>
    <name>BbVideoDeviceSelectorControl</name>
    <message>
        <source>Front Camera</source>
        <translation>Передня камера</translation>
    </message>
    <message>
        <source>Rear Camera</source>
        <translation>Задня камера</translation>
    </message>
    <message>
        <source>Desktop Camera</source>
        <translation>Камера стільниці</translation>
    </message>
</context>
<context>
    <name>CameraBinImageCapture</name>
    <message>
        <source>Camera not ready</source>
        <translation>Камера не готова</translation>
    </message>
</context>
<context>
    <name>CameraBinImageEncoder</name>
    <message>
        <source>JPEG image</source>
        <translation>Зображення JPEG</translation>
    </message>
</context>
<context>
    <name>CameraBinRecorder</name>
    <message>
        <source>QMediaRecorder::pause() is not supported by camerabin2.</source>
        <translation>QMediaRecorder::pause() не підтримується camerabin2.</translation>
    </message>
    <message>
        <source>Service has not been started</source>
        <translation>Сервіс не було запущено</translation>
    </message>
    <message>
        <source>Recording permissions are not available</source>
        <translation>Дозволи на запис недоступні</translation>
    </message>
</context>
<context>
    <name>CameraBinSession</name>
    <message>
        <source>Camera error</source>
        <translation>Помилка камери</translation>
    </message>
</context>
<context>
    <name>DSCameraSession</name>
    <message>
        <source>Camera not ready for capture</source>
        <translation>Камера не готова для захоплення</translation>
    </message>
    <message>
        <source>Could not save image to file.</source>
        <translation>Не вдалось зберегти зображення до файлу.</translation>
    </message>
</context>
<context>
    <name>MFPlayerSession</name>
    <message>
        <source>Invalid stream source.</source>
        <translation>Неправильне джерело потоку.</translation>
    </message>
    <message>
        <source>Attempting to play invalid Qt resource.</source>
        <translation>Спроба відтворити неправильний ресурс Qt.</translation>
    </message>
    <message>
        <source>The system cannot find the file specified.</source>
        <translation>Система не може знайти вказаний файл.</translation>
    </message>
    <message>
        <source>The specified server could not be found.</source>
        <translation>Неможливо знайти вказаний сервер.</translation>
    </message>
    <message>
        <source>Unsupported media type.</source>
        <translation>Непідтримуваний тип медіа.</translation>
    </message>
    <message>
        <source>Failed to load source.</source>
        <translation>Збій завантаженн джерела.</translation>
    </message>
    <message>
        <source>Cannot create presentation descriptor.</source>
        <translation>Неможливо створити дескриптор представлення.</translation>
    </message>
    <message>
        <source>Failed to get stream count.</source>
        <translation>Збій отримання кількості потоків.</translation>
    </message>
    <message>
        <source>Failed to create topology.</source>
        <translation>Збій створення топології.</translation>
    </message>
    <message>
        <source>Unable to play any stream.</source>
        <translation>Неможливо відтворити жодний потік.</translation>
    </message>
    <message>
        <source>Unable to play.</source>
        <translation>Неможливо відтворити.</translation>
    </message>
    <message>
        <source>Failed to set topology.</source>
        <translation>Збій встановлення топології.</translation>
    </message>
    <message>
        <source>Unknown stream type.</source>
        <translation>Невідомий тип потоку.</translation>
    </message>
    <message>
        <source>Failed to stop.</source>
        <translation>Збій зупинки.</translation>
    </message>
    <message>
        <source>failed to start playback</source>
        <translation>збій запуску відтворення</translation>
    </message>
    <message>
        <source>Failed to pause.</source>
        <translation>Збій паузи.</translation>
    </message>
    <message>
        <source>Unable to create mediasession.</source>
        <translation>Неможливо створити медіа-сесію.</translation>
    </message>
    <message>
        <source>Unable to pull session events.</source>
        <translation>Неможливо отримати події сесії.</translation>
    </message>
    <message>
        <source>Failed to seek.</source>
        <translation>Збій переміщення.</translation>
    </message>
    <message>
        <source>Media session non-fatal error.</source>
        <translation>Нефатальна помилка медіа-сесії.</translation>
    </message>
    <message>
        <source>Media session serious error.</source>
        <translation>Серйозна помилка медіа-сесії.</translation>
    </message>
    <message>
        <source>Unsupported media, a codec is missing.</source>
        <translation>Непідтримувана медіа, .відсутній кодек.</translation>
    </message>
</context>
<context>
    <name>PLSParser</name>
    <message>
        <source>Error parsing playlist: %1, expected count = %2</source>
        <translation type="vanished">Помилка розбору списку відтворення: %1, очікувана кількість = %2</translation>
    </message>
    <message>
        <source>Error parsing playlist at line[%1], expected version = 2</source>
        <translation type="vanished">Помилка розбору списку відтворення в рядку [%1], очікувана версія = 2</translation>
    </message>
    <message>
        <source>Error parsing playlist at line[%1]:%2</source>
        <translation type="vanished">Помилка розбору списку відтворення в рядку [%1]:%2</translation>
    </message>
    <message>
        <source>File%1</source>
        <translation type="vanished">Файл%1</translation>
    </message>
    <message>
        <source>Title%1</source>
        <translation type="vanished">Назва%1</translation>
    </message>
    <message>
        <source>Length%1</source>
        <translation type="vanished">Довжина%1</translation>
    </message>
</context>
<context>
    <name>QAndroidAudioEncoderSettingsControl</name>
    <message>
        <source>Adaptive Multi-Rate Narrowband (AMR-NB) audio codec</source>
        <translation>Адаптивний вузькополосне кодування звуку зі змінною швидкістю (AMR-NB)</translation>
    </message>
    <message>
        <source>Adaptive Multi-Rate Wideband (AMR-WB) audio codec</source>
        <translation>Адаптивний широкополосне кодування звуку зі змінною швидкістю (AMR-WB)</translation>
    </message>
    <message>
        <source>AAC Low Complexity (AAC-LC) audio codec</source>
        <translation>Аудіо-кодек AAC низької складності (AAC-LC)</translation>
    </message>
</context>
<context>
    <name>QAndroidCameraSession</name>
    <message>
        <source>Camera cannot be started without a viewfinder.</source>
        <translation>Неможливо запустити камеру без видошукача.</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation>Камера не готова</translation>
    </message>
    <message>
        <source>Drive mode not supported</source>
        <extracomment>Drive mode is the camera&apos;s shutter mode, for example single shot, continuos exposure, etc.</extracomment>
        <translation>Режим не підтримується</translation>
    </message>
    <message>
        <source>Could not open destination file: %1</source>
        <translation>Не вдалось відкрити файл-отримувач: %1</translation>
    </message>
</context>
<context>
    <name>QAndroidImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>Зображення JPEG</translation>
    </message>
</context>
<context>
    <name>QAndroidMediaContainerControl</name>
    <message>
        <source>MPEG4 media file format</source>
        <translation>Медіа-файл формату MPEG4</translation>
    </message>
    <message>
        <source>3GPP media file format</source>
        <translation>Медіа-файл формату 3GPP</translation>
    </message>
    <message>
        <source>AMR NB file format</source>
        <translation>Файл формату AMR NB</translation>
    </message>
    <message>
        <source>AMR WB file format</source>
        <translation>Файл формату AMR WB</translation>
    </message>
</context>
<context>
    <name>QAndroidVideoEncoderSettingsControl</name>
    <message>
        <source>H.263 compression</source>
        <translation>Стиснення H.263</translation>
    </message>
    <message>
        <source>H.264 compression</source>
        <translation>Стиснення H.264</translation>
    </message>
    <message>
        <source>MPEG-4 SP compression</source>
        <translation>Стиснення MPEG-4 SP</translation>
    </message>
</context>
<context>
    <name>QAudioDecoder</name>
    <message>
        <source>The QAudioDecoder object does not have a valid service</source>
        <translation>Об&apos;єкт QAudioDecoder не має правильного сервісу</translation>
    </message>
</context>
<context>
    <name>QCamera</name>
    <message>
        <source>The camera service is missing</source>
        <translation>Сервіс камери відсутній</translation>
    </message>
</context>
<context>
    <name>QCameraImageCapture</name>
    <message>
        <source>Device does not support images capture.</source>
        <translation>Пристрій не підтримує захоплення зображень.</translation>
    </message>
</context>
<context>
    <name>QCameraPrivate</name>
    <message>
        <source>The camera service is missing</source>
        <translation type="obsolete">Сервіс камери відсутній</translation>
    </message>
</context>
<context>
    <name>QDeclarativeAudio</name>
    <message>
        <source>volume should be between 0.0 and 1.0</source>
        <translation>гучність має бути між 0.0 та 1.0</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioDecoderSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Неможливо відтворити потік типу: &lt;невідомо&gt;</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioEncode</name>
    <message>
        <source>Raw PCM audio</source>
        <translation>Сире PCM-аудіо</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioInputSelector</name>
    <message>
        <source>System default device</source>
        <translation>Типовий пристрій системи</translation>
    </message>
</context>
<context>
    <name>QGstreamerCameraControl</name>
    <message>
        <source>State not supported.</source>
        <translation>Стан не підтримується.</translation>
    </message>
</context>
<context>
    <name>QGstreamerCaptureSession</name>
    <message>
        <source>Could not create an audio source element</source>
        <translation>Не вдалось створити елемент джерела аудіо</translation>
    </message>
    <message>
        <source>Failed to build media capture pipeline.</source>
        <translation>Збій побудови конвеєра захоплення медіа.</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageCaptureControl</name>
    <message>
        <source>Not ready to capture</source>
        <translation>Не готово для захоплення</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageEncode</name>
    <message>
        <source>JPEG image encoder</source>
        <translation>Кодувальник зображень JPEG</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerControl</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation type="vanished">Спроба відтворити неправильний ресурс Qt</translation>
    </message>
    <message>
        <source>Attempting to play invalid user stream</source>
        <translation>Спроба відтворити неправильний потік користувача</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Неможливо відтворити потік типу: &lt;невідомо&gt;</translation>
    </message>
    <message>
        <source>UDP source timeout</source>
        <translation>Час очікування джерела UDP вичерпано</translation>
    </message>
    <message>
        <source>Media is loaded as a playlist</source>
        <translation>Медіа завантажено як список відтворення</translation>
    </message>
</context>
<context>
    <name>QGstreamerRecorderControl</name>
    <message>
        <source>Service has not been started</source>
        <translation>Сервіс не було запущено</translation>
    </message>
    <message>
        <source>Not compatible codecs and container format.</source>
        <translation>Несумісні кодеки та формат контейнера.</translation>
    </message>
</context>
<context>
    <name>QGstreamerVideoInputDeviceControl</name>
    <message>
        <source>Main camera</source>
        <translation>Головна камера</translation>
    </message>
    <message>
        <source>Front camera</source>
        <translation>Передня камера</translation>
    </message>
</context>
<context>
    <name>QMediaPlayer</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation>Спроба відтворити неправильний ресурс Qt</translation>
    </message>
    <message>
        <source>The QMediaPlayer object does not have a valid service</source>
        <translation>Об&apos;єкт QMediaPlayer не має правильного сервісу</translation>
    </message>
</context>
<context>
    <name>QMediaPlaylist</name>
    <message>
        <source>Could not add items to read only playlist.</source>
        <translation>Не вдалось додати елементи до списку відтворення лише для читання.</translation>
    </message>
    <message>
        <source>Playlist format is not supported</source>
        <translation>Формат списку відтворення не підтримується</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Не вдалось отримати доступ до файлу.</translation>
    </message>
    <message>
        <source>Playlist format is not supported.</source>
        <translation>Формат списку відтворення не підтримується.</translation>
    </message>
</context>
<context>
    <name>QMultimediaDeclarativeModule</name>
    <message>
        <source>CameraCapture is provided by Camera</source>
        <translation>Камера надає CameraCapture</translation>
    </message>
    <message>
        <source>CameraRecorder is provided by Camera</source>
        <translation>Камера надає CameraRecorder</translation>
    </message>
    <message>
        <source>CameraExposure is provided by Camera</source>
        <translation>Камера надає CameraExposure</translation>
    </message>
    <message>
        <source>CameraFocus is provided by Camera</source>
        <translation>Камера надає CameraFocus</translation>
    </message>
    <message>
        <source>CameraFlash is provided by Camera</source>
        <translation>Камера надає CameraFlash</translation>
    </message>
    <message>
        <source>CameraImageProcessing is provided by Camera</source>
        <translation>Камера надає CameraImageProcessing</translation>
    </message>
    <message>
        <source>CameraViewfinder is provided by Camera</source>
        <translation>Камера надає CameraViewfinder</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation>Невідомий тип списку відтворення %1</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation>неправильний рядок в файлі списку відтворення</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation>Надано порожній файл</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParser</name>
    <message>
        <source>%1 does not exist</source>
        <translation>%1 не існує</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParserPrivate</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation type="vanished">Невідомий тип списку відтворення %1</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation type="vanished">неправильний рядок в файлі списку відтворення</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation type="vanished">Надано порожній файл</translation>
    </message>
</context>
<context>
    <name>QWinRTCameraImageCaptureControl</name>
    <message>
        <source>Camera not ready</source>
        <translation>Камера не готова</translation>
    </message>
    <message>
        <source>Invalid photo data length.</source>
        <translation>Неправильна довжина даних фото.</translation>
    </message>
    <message>
        <source>Image saving failed</source>
        <translation>Збій збереження зображення</translation>
    </message>
</context>
</TS>
